require 'codefusion/firebase_create_command'
require 'codefusion/firebase_update_command'

class Classroom
  attr_reader :path, :parent_dir, :file
  include FirebaseUpdateCommand
  include FirebaseCreateCommand

  def initialize(path, file)
    @path = path
    @dir = path.split('/').last
    @parent_dir = File.dirname(path)
    @code = new_code
    @file = file
    update
  end

  def update
    request = [@code, make_hash]
    if @uuid
      FirebaseUpdateCommand.update(request, @uuid)
    else
      @uuid = set_uuid(FirebaseCreateCommand.create(request))
    end
  end

  def url
    generate_url
  end

  private
  def generate_url
    "http://codefusion.io/#/classrooms/#{@code}"
  end

  def new_code
    current_codes.include?(generate_code) ? new_code : generate_code
  end

  def generate_code
    SecureRandom::hex(2)
  end

  def current_codes
    FirebaseCommand.classroom_codes
  end

  def set_uuid(response)
    response["name"]
  end

  def make_hash
    if @file == ""
      DirParser.make_hash(@dir, @parent_dir)
    else
      FileParser.make_hash(@path, @file, @parent_dir)
    end
  end
end