class Listener
  def initialize(classroom)
    @classroom = classroom
  end

  def start
    begin
      View.listen_message(@classroom.path, url)
      set_listener.start
      sleep
    rescue Exception => e
      View.exit_message
    end
  end

  private
  def set_listener
    Listen.to(@classroom.path, only: this_file) do |modified, added, removed|
      relative_path = get_relative_path(modified, added, removed)
      send_message(applicable_message(modified, added, removed), relative_path)
      @classroom.update
    end
  end

  def applicable_message(modified, added, removed)
    if modified.any?
      :modified_message
    elsif added.any? && removed.any?
      :name_changed_message
    elsif added.any?
      :added_message
    else removed.any?
      :removed_message
    end
  end

  def this_file
    @classroom.file ? Regexp.new(@classroom.file) : /./
  end

  def get_relative_path(modified, added, removed)
    full_path = [modified, added, removed].select { |effect| effect.any? }.flatten.first
    FileParser.shortened_path(full_path, @classroom.parent_dir)
  end

  def url
    @classroom.url
  end

  def send_message(message, path)
    View.send(message, path, url)
  end
end